@@ -27,6 +27,7 @@ install("fastdtw")
 ##----------------------------------------------IMPORTS---------------------------------------------------------------------------#	
 import json
 import ast
+import copy
 from fastdtw import fastdtw
 from scipy.spatial.distance import euclidean
 import pandas as pd
@@ -505,7 +506,7 @@ def graph_features(DiG,df):
     output = merge_dataframes(output, df_nodes_self_loop_iteration)
     return output
 
-def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret, n_groups=1,save_by=300, filepath, filename):
+def user_timeline_extraction(node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret,filepath, filename,n_groups=1,save_by=300):
     # get_user Returns the 20 most recent statuses posted from the authenticating user or the user specified. 
     profile_iter = save_by
     k=0
@@ -1100,11 +1101,11 @@ def NLP_analysis(data, keyword_corpus, hashtag_corpus):
 			data["positive_opinion"] = (len(tweets_df[tweets_df["terrorist_suggestion"]==6]) / tweets_irr_words)
 	return data,tweets_df
 	
-def more_tweets_required(df,df_graph_features,consumerKey,consumerSecret,accessToken,accessTokenSecret,n_groups,save_by,filepath,filename):
+def more_tweets_required(df,df_graph_features,consumerKey,consumerSecret,accessToken,accessTokenSecret,filepath,filename,n_groups,save_by):
 	df_evaluate = df[(df["evaluate_NLP"] !="No") & (df["evaluate_NLP"] !="More Data")]
 	node_list_moreData = list(df[df["evaluate_NLP"]=="More Data"]["screen_name"])
 	if len(node_list_moreData) >0:
-		df_metadata_moreData, list_more_Data_noData = user_timeline_extraction(node_list_moreData,consumerKey,consumerSecret,accessToken,accessTokenSecret,n_groups,save_by,filepath, filename)
+		df_metadata_moreData, list_more_Data_noData = user_timeline_extraction(node_list_moreData,consumerKey,consumerSecret,accessToken,accessTokenSecret,filepath, filename,n_groups,save_by)
 		df_metadata_moreData = pd.read_csv(filepath + filename)
 		df_metadata_moreData = text_to_list_features_conversor(df_metadata_moreData)
 		df_metadata_moreData = advanced_features(df_metadata_moreData)
